flutter_secure_dotenv library

Securely manage environment variables with AES-CBC encryption.

Provides DotEnvGen for annotating classes, AESCBCEncrypter for encryption/decryption, and FieldKey/FieldRename for field configuration.

Classes

AESCBCEncrypter
A class that provides AES encryption and decryption using CBC mode.
DotEnvGen
A generator for handling environment variables.
FieldKey
Represents a key in the environment variables.
Uint8List
A fixed-length list of 8-bit unsigned integers.

Enums

FieldRename
Values for the automatic field renaming behavior for DotEnvGen.

Constants

base64 → const Base64Codec
A base64 encoder and decoder.
json → const JsonCodec
An instance of the default implementation of the JsonCodec.